@@ -15,11 +15,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef QGSCURVEPOLYGONV2_H
-#define QGSCURVEPOLYGONV2_H
+#ifndef QGSCURVEPOLYGON_H
+#define QGSCURVEPOLYGON_H
 
 #include "qgis_core.h"
-#include "qgis.h"
+#include "qgis_sip.h"
 #include "qgssurface.h"
 #include <memory>
 
@@ -55,7 +55,8 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     QString asWkt( int precision = 17 ) const override;
     QDomElement asGml2( QDomDocument &doc, int precision = 17, const QString &ns = "gml", QgsAbstractGeometry::AxisOrder axisOrder = QgsAbstractGeometry::AxisOrder::XY ) const override;
     QDomElement asGml3( QDomDocument &doc, int precision = 17, const QString &ns = "gml", QgsAbstractGeometry::AxisOrder axisOrder = QgsAbstractGeometry::AxisOrder::XY ) const override;
-    QString asJson( int precision = 17 ) const override;
+    json asJsonObject( int precision = 17 ) const override SIP_SKIP;
+    QString asKml( int precision = 17 ) const override;
 
     //surface interface
     double area() const override;
@@ -66,16 +67,35 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     bool removeDuplicateNodes( double epsilon = 4 * std::numeric_limits<double>::epsilon(), bool useZValues = false ) override;
 
     //curve polygon interface
+
+    /**
+     * Returns the number of interior rings contained with the curve polygon.
+     *
+     * \see interiorRing()
+     */
     int numInteriorRings() const
     {
       return mInteriorRings.size();
     }
 
+    /**
+     * Returns the curve polygon's exterior ring.
+     *
+     * \see interiorRing()
+     */
     const QgsCurve *exteriorRing() const
     {
       return mExteriorRing.get();
     }
 
+#ifndef SIP_RUN
+
+    /**
+     * Retrieves an interior ring from the curve polygon. The first interior ring has index 0.
+     *
+     * \see numInteriorRings()
+     * \see exteriorRing()
+     */
     const QgsCurve *interiorRing( int i ) const
     {
       if ( i < 0 || i >= mInteriorRings.size() )
@@ -84,6 +104,29 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
       }
       return mInteriorRings.at( i );
     }
+#else
+
+    /**
+     * Retrieves an interior ring from the curve polygon. The first interior ring has index 0.
+     *
+     * An IndexError will be raised if no interior ring with the specified index exists.
+     *
+     * \see numInteriorRings()
+     * \see exteriorRing()
+     */
+    SIP_PYOBJECT interiorRing( int i ) SIP_TYPEHINT( QgsCurve );
+    % MethodCode
+    if ( a0 < 0 || a0 >= sipCpp->numInteriorRings() )
+    {
+      PyErr_SetString( PyExc_IndexError, QByteArray::number( a0 ) );
+      sipIsErr = 1;
+    }
+    else
+    {
+      return sipConvertFromType( const_cast< QgsCurve * >( sipCpp->interiorRing( a0 ) ), sipType_QgsCurve, NULL );
+    }
+    % End
+#endif
 
     /**
      * Returns a new polygon geometry corresponding to a segmentized approximation
@@ -107,13 +150,39 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
     //! Adds an interior ring to the geometry (takes ownership)
     virtual void addInteriorRing( QgsCurve *ring SIP_TRANSFER );
 
+#ifndef SIP_RUN
+
     /**
      * Removes an interior ring from the polygon. The first interior ring has index 0.
      * The corresponding ring is removed from the polygon and deleted. If a ring was successfully removed
-     * the function will return true.  It is not possible to remove the exterior ring using this method.
+     * the function will return TRUE.  It is not possible to remove the exterior ring using this method.
      * \see removeInteriorRings()
      */
     bool removeInteriorRing( int ringIndex );
+#else
+
+    /**
+     * Removes an interior ring from the polygon. The first interior ring has index 0.
+     * The corresponding ring is removed from the polygon and deleted.
+     * It is not possible to remove the exterior ring using this method.
+     *
+     * An IndexError will be raised if no interior ring with the specified index exists.
+     *
+     * \see removeInteriorRings()
+     */
+    bool removeInteriorRing( int i );
+    % MethodCode
+    if ( a0 < 0 || a0 >= sipCpp->numInteriorRings() )
+    {
+      PyErr_SetString( PyExc_IndexError, QByteArray::number( a0 ) );
+      sipIsErr = 1;
+    }
+    else
+    {
+      return PyBool_FromLong( sipCpp->removeInteriorRing( a0 ) );
+    }
+    % End
+#endif
 
     /**
      * Removes the interior rings from the polygon. If the minimumAllowedArea
@@ -133,14 +202,13 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
      */
     void removeInvalidRings();
 
-
     /**
      * Forces the geometry to respect the Right-Hand-Rule, in which the area that is
      * bounded by the polygon is to the right of the boundary. In particular, the exterior
      * ring is oriented in a clockwise direction and the interior rings in a counter-clockwise
      * direction.
      *
-     * \since QGIS 3.4.3
+     * \since QGIS 3.6
      */
     void forceRHR();
 
@@ -242,4 +310,4 @@ class CORE_EXPORT QgsCurvePolygon: public QgsSurface
 
 // clazy:excludeall=qstring-allocations
 
-#endif // QGSCURVEPOLYGONV2_H
+#endif // QGSCURVEPOLYGON_H
